==> haskell-tasty-hedgehog-1.0.0.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 1.0.0.1
id: tasty-hedgehog-1.0.0.1-Kz0NTutYiLJcUxK12WPaL
key: tasty-hedgehog-1.0.0.1-Kz0NTutYiLJcUxK12WPaL
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedgehog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.
category: Testing
abi: 2e670230acf88db20fcc901e60a297e5
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hedgehog-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hedgehog-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-hedgehog-1.0.0.1
hs-libraries: HStasty-hedgehog-1.0.0.1-Kz0NTutYiLJcUxK12WPaL
depends:
    base-4.12.0.0 hedgehog-1.0-9y4dauJ9zS62dUY9iH535O
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.0.0.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hedgehog
version: 1.0.0.1
id: tasty-hedgehog-1.0.0.1-HCcaOz8lMfHH3SWrAdtkks
key: tasty-hedgehog-1.0.0.1-HCcaOz8lMfHH3SWrAdtkks
license: BSD-3-Clause
copyright: Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.
maintainer: dave.laing.80@gmail.com
author: Dave Laing
homepage: https://github.com/qfpl/tasty-hedgehog
synopsis: Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.
category: Testing
abi: db1807902f77f71d6072aae2ee2aa615
exposed: True
exposed-modules:
    Test.Tasty.Hedgehog
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hedgehog-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hedgehog-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-hedgehog-1.0.0.1
hs-libraries: HStasty-hedgehog-1.0.0.1-HCcaOz8lMfHH3SWrAdtkks
depends:
    base-4.12.0.0 hedgehog-1.0-Kvqh3KVyCJh9a85VQ4cjTV
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
haddock-interfaces: /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock
haddock-html: /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
